@@ -20,17 +20,17 @@ class Error:
             self.details: str = None
 
 
-class CancelFeedResponse:
+class ErrorList:
     def __init__(self, data):
         super().__init__()
         self.data = data
         if "errors" in data:
-            self.errors: ErrorList = ErrorList(data["errors"])
+            self.errors: _List[Error] = [Error(datum) for datum in data["errors"]]
         else:
-            self.errors: ErrorList = None
+            self.errors: _List[Error] = []
 
 
-class CreateFeedResult:
+class CreateFeedResponse:
     def __init__(self, data):
         super().__init__()
         self.data = data
@@ -82,50 +82,14 @@ class GetFeedsResponse:
     def __init__(self, data):
         super().__init__()
         self.data = data
-        if "payload" in data:
-            self.payload: FeedList = FeedList(data["payload"])
+        if "feeds" in data:
+            self.feeds: FeedList = FeedList(data["feeds"])
         else:
-            self.payload: FeedList = None
+            self.feeds: FeedList = None
         if "nextToken" in data:
             self.nextToken: str = str(data["nextToken"])
         else:
             self.nextToken: str = None
-        if "errors" in data:
-            self.errors: ErrorList = ErrorList(data["errors"])
-        else:
-            self.errors: ErrorList = None
-
-
-class GetFeedResponse:
-    def __init__(self, data):
-        super().__init__()
-        self.data = data
-        if "payload" in data:
-            self.payload: Feed = Feed(data["payload"])
-        else:
-            self.payload: Feed = None
-        if "errors" in data:
-            self.errors: ErrorList = ErrorList(data["errors"])
-        else:
-            self.errors: ErrorList = None
-
-
-class FeedDocumentEncryptionDetails:
-    def __init__(self, data):
-        super().__init__()
-        self.data = data
-        if "standard" in data:
-            self.standard: str = str(data["standard"])
-        else:
-            self.standard: str = None
-        if "initializationVector" in data:
-            self.initializationVector: str = str(data["initializationVector"])
-        else:
-            self.initializationVector: str = None
-        if "key" in data:
-            self.key: str = str(data["key"])
-        else:
-            self.key: str = None
 
 
 class FeedDocument:
@@ -140,46 +104,12 @@ class FeedDocument:
             self.url: str = str(data["url"])
         else:
             self.url: str = None
-        if "encryptionDetails" in data:
-            self.encryptionDetails: FeedDocumentEncryptionDetails = FeedDocumentEncryptionDetails(
-                data["encryptionDetails"]
-            )
-        else:
-            self.encryptionDetails: FeedDocumentEncryptionDetails = None
         if "compressionAlgorithm" in data:
             self.compressionAlgorithm: str = str(data["compressionAlgorithm"])
         else:
             self.compressionAlgorithm: str = None
 
 
-class GetFeedDocumentResponse:
-    def __init__(self, data):
-        super().__init__()
-        self.data = data
-        if "payload" in data:
-            self.payload: FeedDocument = FeedDocument(data["payload"])
-        else:
-            self.payload: FeedDocument = None
-        if "errors" in data:
-            self.errors: ErrorList = ErrorList(data["errors"])
-        else:
-            self.errors: ErrorList = None
-
-
-class CreateFeedResponse:
-    def __init__(self, data):
-        super().__init__()
-        self.data = data
-        if "payload" in data:
-            self.payload: CreateFeedResult = CreateFeedResult(data["payload"])
-        else:
-            self.payload: CreateFeedResult = None
-        if "errors" in data:
-            self.errors: ErrorList = ErrorList(data["errors"])
-        else:
-            self.errors: ErrorList = None
-
-
 class FeedOptions:
     def __init__(self, data):
         super().__init__()
@@ -219,20 +149,6 @@ class CreateFeedDocumentSpecification:
 
 
 class CreateFeedDocumentResponse:
-    def __init__(self, data):
-        super().__init__()
-        self.data = data
-        if "payload" in data:
-            self.payload: CreateFeedDocumentResult = CreateFeedDocumentResult(data["payload"])
-        else:
-            self.payload: CreateFeedDocumentResult = None
-        if "errors" in data:
-            self.errors: ErrorList = ErrorList(data["errors"])
-        else:
-            self.errors: ErrorList = None
-
-
-class CreateFeedDocumentResult:
     def __init__(self, data):
         super().__init__()
         self.data = data
@@ -244,18 +160,6 @@ class CreateFeedDocumentResult:
             self.url: str = str(data["url"])
         else:
             self.url: str = None
-        if "encryptionDetails" in data:
-            self.encryptionDetails: FeedDocumentEncryptionDetails = FeedDocumentEncryptionDetails(
-                data["encryptionDetails"]
-            )
-        else:
-            self.encryptionDetails: FeedDocumentEncryptionDetails = None
-
-
-class ErrorList(list, _List["Error"]):
-    def __init__(self, data):
-        super().__init__([Error(datum) for datum in data])
-        self.data = data
 
 
 class FeedList(list, _List["Feed"]):
@@ -264,7 +168,7 @@ class FeedList(list, _List["Feed"]):
         self.data = data
 
 
-class Feeds20200904Client(__BaseClient):
+class Feeds20210630Client(__BaseClient):
     def getFeeds(
         self,
         feedTypes: _List[str] = None,
@@ -275,7 +179,7 @@ class Feeds20200904Client(__BaseClient):
         createdUntil: str = None,
         nextToken: str = None,
     ):
-        url = "/feeds/2020-09-04/feeds".format()
+        url = "/feeds/2021-06-30/feeds".format()
         params = {}
         if feedTypes is not None:
             params["feedTypes"] = ",".join(map(str, feedTypes))
@@ -294,113 +198,112 @@ class Feeds20200904Client(__BaseClient):
         response = self.request(url, method="GET", params=params)
         return {
             200: GetFeedsResponse,
-            400: GetFeedsResponse,
-            401: GetFeedsResponse,
-            403: GetFeedsResponse,
-            404: GetFeedsResponse,
-            415: GetFeedsResponse,
-            429: GetFeedsResponse,
-            500: GetFeedsResponse,
-            503: GetFeedsResponse,
-        }[response.status_code](self.__get_response_json(response))
+            400: ErrorList,
+            401: ErrorList,
+            403: ErrorList,
+            404: ErrorList,
+            415: ErrorList,
+            429: ErrorList,
+            500: ErrorList,
+            503: ErrorList,
+        }[response.status_code](self._get_response_json(response))
 
     def createFeed(
         self,
         data: CreateFeedSpecification,
     ):
-        url = "/feeds/2020-09-04/feeds".format()
+        url = "/feeds/2021-06-30/feeds".format()
         params = {}
         response = self.request(url, method="POST", data=data.data)
         return {
             202: CreateFeedResponse,
-            400: CreateFeedResponse,
-            401: CreateFeedResponse,
-            403: CreateFeedResponse,
-            404: CreateFeedResponse,
-            415: CreateFeedResponse,
-            429: CreateFeedResponse,
-            500: CreateFeedResponse,
-            503: CreateFeedResponse,
-        }[response.status_code](self.__get_response_json(response))
+            400: ErrorList,
+            401: ErrorList,
+            403: ErrorList,
+            404: ErrorList,
+            415: ErrorList,
+            429: ErrorList,
+            500: ErrorList,
+            503: ErrorList,
+        }[response.status_code](self._get_response_json(response))
 
     def getFeed(
         self,
         feedId: str,
     ):
-        url = "/feeds/2020-09-04/feeds/{feedId}".format(
+        url = "/feeds/2021-06-30/feeds/{feedId}".format(
             feedId=feedId,
         )
         params = {}
         response = self.request(url, method="GET", params=params)
         return {
-            200: GetFeedResponse,
-            400: GetFeedResponse,
-            401: GetFeedResponse,
-            403: GetFeedResponse,
-            404: GetFeedResponse,
-            415: GetFeedResponse,
-            429: GetFeedResponse,
-            500: GetFeedResponse,
-            503: GetFeedResponse,
-        }[response.status_code](self.__get_response_json(response))
+            200: Feed,
+            400: ErrorList,
+            401: ErrorList,
+            403: ErrorList,
+            404: ErrorList,
+            415: ErrorList,
+            429: ErrorList,
+            500: ErrorList,
+            503: ErrorList,
+        }[response.status_code](self._get_response_json(response))
 
     def cancelFeed(
         self,
         feedId: str,
     ):
-        url = "/feeds/2020-09-04/feeds/{feedId}".format(
+        url = "/feeds/2021-06-30/feeds/{feedId}".format(
             feedId=feedId,
         )
         params = {}
         response = self.request(url, method="DELETE", data=data.data)
         return {
-            200: CancelFeedResponse,
-            400: CancelFeedResponse,
-            401: CancelFeedResponse,
-            403: CancelFeedResponse,
-            404: CancelFeedResponse,
-            415: CancelFeedResponse,
-            429: CancelFeedResponse,
-            500: CancelFeedResponse,
-            503: CancelFeedResponse,
-        }[response.status_code](self.__get_response_json(response))
+            400: ErrorList,
+            401: ErrorList,
+            403: ErrorList,
+            404: ErrorList,
+            415: ErrorList,
+            429: ErrorList,
+            500: ErrorList,
+            503: ErrorList,
+        }[response.status_code](self._get_response_json(response))
 
     def createFeedDocument(
         self,
         data: CreateFeedDocumentSpecification,
     ):
-        url = "/feeds/2020-09-04/documents".format()
+        url = "/feeds/2021-06-30/documents".format()
         params = {}
         response = self.request(url, method="POST", data=data.data)
         return {
             201: CreateFeedDocumentResponse,
-            400: CreateFeedDocumentResponse,
-            403: CreateFeedDocumentResponse,
-            404: CreateFeedDocumentResponse,
-            413: CreateFeedDocumentResponse,
-            415: CreateFeedDocumentResponse,
-            429: CreateFeedDocumentResponse,
-            500: CreateFeedDocumentResponse,
-            503: CreateFeedDocumentResponse,
-        }[response.status_code](self.__get_response_json(response))
+            400: ErrorList,
+            403: ErrorList,
+            404: ErrorList,
+            413: ErrorList,
+            415: ErrorList,
+            429: ErrorList,
+            500: ErrorList,
+            503: ErrorList,
+        }[response.status_code](self._get_response_json(response))
 
     def getFeedDocument(
         self,
         feedDocumentId: str,
     ):
-        url = "/feeds/2020-09-04/documents/{feedDocumentId}".format(
+        url = "/feeds/2021-06-30/documents/{feedDocumentId}".format(
             feedDocumentId=feedDocumentId,
         )
         params = {}
         response = self.request(url, method="GET", params=params)
         return {
-            200: GetFeedDocumentResponse,
-            400: GetFeedDocumentResponse,
-            401: GetFeedDocumentResponse,
-            403: GetFeedDocumentResponse,
-            404: GetFeedDocumentResponse,
-            415: GetFeedDocumentResponse,
-            429: GetFeedDocumentResponse,
-            500: GetFeedDocumentResponse,
-            503: GetFeedDocumentResponse,
-        }[response.status_code](self.__get_response_json(response))
+            200: FeedDocument,
+            400: ErrorList,
+            401: ErrorList,
+            403: ErrorList,
+            404: ErrorList,
+            415: ErrorList,
+            429: ErrorList,
+            500: ErrorList,
+            503: ErrorList,
+        }[response.status_code](self._get_response_json(response))
